liblzma: Rename LZMA_SEEK to LZMA_SEEK_NEEDED and seek_in to seek_pos.
diff --git a/src/liblzma/common/common.c b/src/liblzma/common/common.c
index 8ffe976..1399b92 100644
--- a/src/liblzma/common/common.c
+++ b/src/liblzma/common/common.c
@@ -317,7 +317,7 @@
 		ret = LZMA_OK;
 		break;
 
-	case LZMA_SEEK:
+	case LZMA_SEEK_NEEDED:
 		strm->internal->allow_buf_error = false;
 
 		// If LZMA_FINISH was used, reset it back to the
diff --git a/src/xz/message.c b/src/xz/message.c
index 41de60c..7e9ec53 100644
--- a/src/xz/message.c
+++ b/src/xz/message.c
@@ -818,7 +818,7 @@
 	case LZMA_STREAM_END:
 	case LZMA_GET_CHECK:
 	case LZMA_PROG_ERROR:
-	case LZMA_SEEK:
+	case LZMA_SEEK_NEEDED:
 		// Without "default", compiler will warn if new constants
 		// are added to lzma_ret, it is not too easy to forget to
 		// add the new constants to this function.
diff --git a/src/liblzma/api/lzma/base.h b/src/liblzma/api/lzma/base.h
index 9b3e9e1..566247a 100644
--- a/src/liblzma/api/lzma/base.h
+++ b/src/liblzma/api/lzma/base.h
@@ -235,16 +235,16 @@
 		 * how to report bugs.
 		 */
 
-	LZMA_SEEK               = 12
+	LZMA_SEEK_NEEDED        = 12
 		/**<
 		 * \brief       Request to change the input file position
 		 *
 		 * Some coders can do random access in the input file. The
 		 * initialization functions of these coders take the file size
 		 * as an argument. No other coders can return LZMA_SEEK.
 		 *
 		 * When this value is returned, the application must seek to
 		 * the file position given in lzma_stream.seek_in. This value
 		 * is guaranteed to never exceed the file size that was
 		 * specified at the coder initialization.
 		 *
@@ -533,16 +533,16 @@
 	void *reserved_ptr4;
 
 	/**
 	 * \brief       New seek input position for LZMA_SEEK
 	 *
 	 * When lzma_code() returns LZMA_SEEK, the new input position needed
 	 * by liblzma will be available seek_in. The value is guaranteed to
 	 * not exceed the file size that was specified when this lzma_stream
 	 * was initialized.
 	 *
 	 * In all other situations the value of this variable is undefined.
 	 */
-	uint64_t seek_in;
+	uint64_t seek_pos;
 
 	uint64_t reserved_int2;
 	size_t reserved_int3;
@@ -235,16 +235,16 @@
 		 * Some coders can do random access in the input file. The
 		 * initialization functions of these coders take the file size
-		 * as an argument. No other coders can return LZMA_SEEK.
+		 * as an argument. No other coders can return LZMA_SEEK_NEEDED.
 		 *
 		 * When this value is returned, the application must seek to
@@ -235,16 +235,16 @@
 		 *
 		 * When this value is returned, the application must seek to
-		 * the file position given in lzma_stream.seek_in. This value
+		 * the file position given in lzma_stream.seek_pos. This value
 		 * is guaranteed to never exceed the file size that was
 		 * specified at the coder initialization.
@@ -533,16 +533,16 @@
 
 	/**
-	 * \brief       New seek input position for LZMA_SEEK
+	 * \brief       New seek input position for LZMA_SEEK_NEEDED
 	 *
@@ -533,16 +533,16 @@
 	 *
-	 * When lzma_code() returns LZMA_SEEK, the new input position needed
-	 * by liblzma will be available seek_in. The value is guaranteed to
-	 * not exceed the file size that was specified when this lzma_stream
-	 * was initialized.
+	 * When lzma_code() returns LZMA_SEEK_NEEDED, the new input position
+	 * needed by liblzma will be available seek_pos. The value is
+	 * guaranteed to not exceed the file size that was specified when
+	 * this lzma_stream was initialized.
 	 *
 	 * In all other situations the value of this variable is undefined.